pub struct Materialize {
pub anchor: Span,
pub edit_span: Span,
pub edit_text: String,
}Expand description
The data the ghost given inlay hint needs to render and one-click apply.
Fields
anchor: SpanWhere the ghost clause renders — the end of the handler’s return type.
edit_span: SpanThe text edit that writes the real given Cap (or , Cap) clause.
edit_text: StringTrait Implementations
Sourceimpl Clone for Materialize
impl Clone for Materialize
Sourcefn clone(&self) -> Materialize
fn clone(&self) -> Materialize
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for Materialize
impl Debug for Materialize
Sourceimpl PartialEq for Materialize
impl PartialEq for Materialize
impl Eq for Materialize
impl StructuralPartialEq for Materialize