ops_for

Function ops_for 

pub fn ops_for(head: &str) -> &'static [StoreOp]
The operations of the storage kind named head (a StoreKind’s head identifier — "Map", "Cell", …). Queue is in the storage-kind catalogue but has no dispatched operations yet, so it — like an unknown head — yields none.